@@ -584,8 +584,8 @@ NSArray *SOGoMailGetDirectChildren(NSArray *_array, NSString *_fn) {
   NSArray *uids, *threadUids;
   NSMutableArray *sortedThreads, *sortedThread;
   NSMutableDictionary *threads;
-  NSEnumerator *threadsEnum, *threadEnum;
-  id rootThread, thread;
+  NSEnumerator *threadsEnum;
+  id rootThread;
   unsigned int i, j;
 
   // Check cache
@@ -614,13 +614,9 @@ NSArray *SOGoMailGetDirectChildren(NSArray *_array, NSString *_fn) {
       i = 0;
       while ((rootThread = [threadsEnum nextObject]))
         {
-          thread = rootThread;
-          while ([thread respondsToSelector: @selector(objectEnumerator)])
-            {
-              threadEnum = [thread objectEnumerator];
-              thread = [threadEnum nextObject];
-            }
-          [threads setObject: rootThread forKey: thread];
+          threadUids = [self _flattenedArray: rootThread];
+          threadUids = [threadUids sortedArrayUsingSelector: @selector (compare:)];
+          [threads setObject: threadUids forKey: [threadUids lastObject]];
         }
 
       // 2. Flatten and sort the threads based on an IMAP SORT
@@ -629,12 +625,11 @@ NSArray *SOGoMailGetDirectChildren(NSArray *_array, NSString *_fn) {
       sortedThreads = [NSMutableArray arrayWithCapacity: [threads count]];
       for (i = 0; i < [uids count]; i++)
         {
-          thread = [threads objectForKey: [uids objectAtIndex: i]];
-          if (thread)
+          threadUids = [threads objectForKey: [uids objectAtIndex: i]];
+          if (threadUids)
             {
-              if ([thread count] > 1)
+              if ([threadUids count] > 1)
                 {
-                  threadUids = [self _flattenedArray: thread];
                   sortedThread = [NSMutableArray arrayWithCapacity: [threadUids count]];
                   for (j = 0; j < [uids count] && [sortedThread count] < [threadUids count]; j++)
                     {
@@ -646,7 +641,7 @@ NSArray *SOGoMailGetDirectChildren(NSArray *_array, NSString *_fn) {
               else
                 {
                   // No sorting required
-                  [sortedThreads addObject: thread];
+                  [sortedThreads addObject: threadUids];
                 }
             }
         }
@@ -1130,6 +1125,23 @@ NSArray *SOGoMailGetDirectChildren(NSArray *_array, NSString *_fn) {
   return nil;
 }
 
+- (NSException *) deleteMailbox: (NSString *)_path
+{
+  id result;
+
+  /* delete */
+
+  result = [[self client] delete: _path];
+  if (![[result valueForKey:@"result"] boolValue])
+    return [self errorForResult:result text:@"Failed to delete folder"];
+
+  [self flushFolderHierarchyCache];
+#if 0
+  [self debugWithFormat:@"delete mailbox %@: %@", _path, result];
+#endif
+  return nil;
+}
+
 - (NSException *)moveMailboxAtURL:(NSURL *)_srcurl toURL:(NSURL *)_desturl {
   NSString *srcname, *destname;
   id result;
@@ -1150,6 +1162,24 @@ NSArray *SOGoMailGetDirectChildren(NSArray *_array, NSString *_fn) {
   return nil;
 }
 
+- (NSException *) moveMailbox: (NSString *)_srcname to:(NSString *)_destname
+{
+  id result;
+
+  /* rename */
+
+  result = [[self client] rename: _srcname to: _destname];
+  if (![[result valueForKey: @"result"] boolValue])
+    return [self errorForResult: result text:@"Failed to move folder"];
+
+  [self flushFolderHierarchyCache];
+#if 0
+  [self debugWithFormat:@"renamed mailbox %@: %@", _srcname, result];
+#endif
+
+  return nil;
+}
+
 /* ACLs */
 
 - (NSDictionary *)aclForMailboxAtURL:(NSURL *)_url {
