@@ -25,7 +25,7 @@
 
 static BOOL isPrintable(char ch) {
   // match printable ASCII-characters according to https://tools.ietf.org/html/rfc2047#section-4.2
-  return ch >= 32 && ch < 127 && ch != '=' && ch != '?' && ch != '_' && ch != ',' && ch != ';' && ch != ':';
+  return ch >= 32 && ch < 127 && ch != '=' && ch != '?' && ch != '_' && ch != ',' && ch != ';' && ch != ':' && ch != '@';
 }
 
 @implementation NGMimeHeaderFieldGenerator
